ArxivLens
ArXiv cs.CV

Partition Pruning: Parallelization-Aware Pruning for Deep Neural Networks

1901.11391 Published Feb 28, 2019
Read paper
More tools
View PDF
At a glance AI-generated · verify against the paper

Researchers developed a method called Partition Pruning to reduce parameters in deep neural networks while considering parallelization, achieving a 7.72x speedup and 2.73x energy reduction.

Abstract

Parameters of recent neural networks require a huge amount of memory. These parameters are used by neural networks to perform machine learning tasks when processing inputs. To speed up inference, we develop Partition Pruning, an innovative scheme to reduce the parameters used while taking into consideration parallelization. We evaluated the performance and energy consumption of parallel inference of partitioned models, which showed a 7.72x speed up of performance and a 2.73x reduction in the energy used for computing pruned layers of TinyVGG16 in comparison to running the unpruned model on a single accelerator. In addition, our method showed a limited reduction some numbers in accuracy while partitioning fully connected layers.

AI Key Findings

Get AI-generated insights about this paper's methodology, results, significance, and more — available when analysis has been generated.

Paper preview View the original document Preview of the original paper

How to Cite This Paper

Reference manager: RIS EndNote

Discussion 0

This website uses cookies to ensure you get the best experience. Learn more